@@ -2,7 +2,7 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2013  Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2008-2013  Luis Falcon <falcon@gnu.org>
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -32,7 +32,9 @@ def register():
         Occupation,
         Ethnicity,
         MedicalSpecialty,
-        Physician,
+        HealthProfessional,
+        HealthProfessionalSpecialties,        
+        PhysicianSP,
         OperationalArea,
         OperationalSector,
         Family,
