@@ -3,7 +3,7 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2013  Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2008-2013  Luis Falcon <falcon@gnu.org>
 #                             Bruno M. Villasanti <bvillasanti@thymbra.com>
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -41,7 +41,7 @@ if __name__ == '__main__':
     try:
         print ">> Attempting to connect..."
         pg_conn = psycopg2.connect(opt.dsn)
-        print ">> Contected!"
+        print ">> Connected!"
         pg_cursor = pg_conn.cursor()
         main(pg_cursor)
         pg_conn.commit()
